//+------------------------------------------------------------------+
//|                                                    MACD Dots.mq4 |
//|                                Copyright  2005, David W. Thomas |
//|                                           mailto:davidwt@usa.net |
//+------------------------------------------------------------------+
// This is the correct computation and display of MACD.
#property copyright "Copyright  2005, David W. Thomas"
#property link      "mailto:davidwt@usa.net"
//Dot code added by cja tsd forum

#property indicator_separate_window
#property indicator_buffers 5
#property indicator_color1 Khaki
#property indicator_color2 Silver
#property indicator_color3 Green
#property indicator_style2 2

#property indicator_color4 DodgerBlue
#property indicator_color5 Red
#property indicator_width4 2
#property indicator_width5 2


//---- input parameters
extern int       FastMAPeriod   = 12;
extern int       SlowMAPeriod   = 26;
extern int       SignalMAPeriod = 9;

extern bool      Show_Histo     = false;
extern bool      Show_ZeroLevel = false;

//---- buffers
double MACDLineBuffer[];
double SignalLineBuffer[];
double HistogramBuffer[];
double Buffer1[];
double Buffer2[];

//---- variables
double alpha = 0;
double alpha_1 = 0;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   IndicatorDigits(MarketInfo(Symbol(),MODE_DIGITS)+1);
   //---- indicators
   SetIndexStyle(0,DRAW_LINE);
   SetIndexBuffer(0,MACDLineBuffer);
   SetIndexDrawBegin(0,SlowMAPeriod);
   
   SetIndexStyle(1,DRAW_LINE);
   SetIndexBuffer(1,SignalLineBuffer);
   SetIndexDrawBegin(1,SlowMAPeriod+SignalMAPeriod);
   
   if(Show_Histo){SetIndexStyle(2,DRAW_HISTOGRAM);}
   else{SetIndexStyle(2,DRAW_NONE);}
   SetIndexBuffer(2,HistogramBuffer);
   SetIndexDrawBegin(2,SlowMAPeriod+SignalMAPeriod);
   
   SetIndexStyle(3,DRAW_ARROW);
   SetIndexArrow(3,159);
   SetIndexBuffer(3,Buffer1);
   
   SetIndexStyle(4,DRAW_ARROW);
   SetIndexArrow(4,159);
   SetIndexBuffer(4,Buffer2);
  
   //---- name for DataWindow and indicator subwindow label
   IndicatorShortName("MACD Dots  ("+FastMAPeriod+","+SlowMAPeriod+","+SignalMAPeriod+")");
   SetIndexLabel(0,"MACD");
   SetIndexLabel(1,"Signal");
   
   SetIndexLabel(2,"");
   SetIndexLabel(3,"");
   SetIndexLabel(4,"");
   //----
	alpha = 2.0 / (SignalMAPeriod + 1.0);
	alpha_1 = 1.0 - alpha;
   //----
   return(0);
}
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
   //---- 
   
   //----
   return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
   if(Show_ZeroLevel){
   SetLevelValue(0,0);
   SetLevelStyle(2,0,DarkSlateGray);
   }if(Show_ZeroLevel==false){
   SetLevelStyle(2,0,CLR_NONE);
   }
   int limit;
   int counted_bars = IndicatorCounted();
   //---- check for possible errors
   if (counted_bars<0) return(-1);
   //---- last counted bar will be recounted
   if (counted_bars>0) counted_bars--;
   limit = Bars - counted_bars;

   for(int i=limit; i>=0; i--)
   {
      MACDLineBuffer[i] = iMA(NULL,0,FastMAPeriod,0,MODE_EMA,PRICE_CLOSE,i) - iMA(NULL,0,SlowMAPeriod,0,MODE_EMA,PRICE_CLOSE,i);
      SignalLineBuffer[i] = alpha*MACDLineBuffer[i] + alpha_1*SignalLineBuffer[i+1];
      HistogramBuffer[i] = MACDLineBuffer[i] - SignalLineBuffer[i];
      
     if((MACDLineBuffer[i]-MACDLineBuffer[i+1])>(MACDLineBuffer[i+1]-MACDLineBuffer[i+2])){Buffer1[i]=MACDLineBuffer[i];Buffer2[i]=EMPTY_VALUE;}
     if((MACDLineBuffer[i]-MACDLineBuffer[i+1])<(MACDLineBuffer[i+1]-MACDLineBuffer[i+2])){Buffer2[i]=MACDLineBuffer[i];Buffer1[i]=EMPTY_VALUE;}

      
   }
   
   //----
   return(0);
}
//+------------------------------------------------------------------+